<?php
$pageTitle = 'Bulk Upload Products';

require_once 'config.php';
require 'vendor/autoload.php';

use PhpOffice\PhpSpreadsheet\IOFactory;

$message = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_FILES['product_file'])) {
    $file = $_FILES['product_file'];
    $allowedExtensions = ['xls', 'xlsx', 'csv'];
    $fileExtension = strtolower(pathinfo($file['name'], PATHINFO_EXTENSION));

    if (in_array($fileExtension, $allowedExtensions)) {
        try {
            $spreadsheet = IOFactory::load($file['tmp_name']);
            $worksheet = $spreadsheet->getActiveSheet();
            $rows = $worksheet->toArray();

            // Remove header row
            array_shift($rows);

            $insertCount = 0;
            foreach ($rows as $row) {
                $stmt = $pdo->prepare("INSERT INTO products (name, description, sku, price, stock_quantity, category, brand, weight, dimensions) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?)");
                $stmt->execute($row);
                $insertCount++;
            }

            $message = "Successfully uploaded $insertCount products.";
        } catch (Exception $e) {
            $message = "Error: " . $e->getMessage();
        }
    } else {
        $message = "Invalid file type. Please upload an Excel file (.xls, .xlsx) or CSV file.";
    }
}

ob_start();
?>

<div class="bg-white p-6 rounded-lg shadow-md">
    <h3 class="text-lg font-semibold text-gray-700 mb-4">Bulk Upload Products</h3>
    
    <?php if ($message): ?>
        <div class="bg-blue-100 border-l-4 border-blue-500 text-blue-700 p-4 mb-4" role="alert">
            <p><?php echo $message; ?></p>
        </div>
    <?php endif; ?>

    <form action="" method="POST" enctype="multipart/form-data">
        <div class="mb-4">
            <label for="product_file" class="block text-gray-700 text-sm font-bold mb-2">Upload Excel or CSV File:</label>
            <input type="file" id="product_file" name="product_file" accept=".xls,.xlsx,.csv" class="shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline">
        </div>
        <div class="flex items-center justify-between">
            <button type="submit" class="bg-orange-500 hover:bg-orange-700 text-white font-bold py-2 px-4 rounded focus:outline-none focus:shadow-outline">
                Upload Products
            </button>
        </div>
    </form>
    
    <div class="mt-4">
        <h4 class="text-md font-semibold text-gray-700 mb-2">File Format:</h4>
        <p class="text-sm text-gray-600">
            Your Excel or CSV file should have the following columns in order:<br>
            Name, Description, SKU, Price, Stock Quantity, Category, Brand, Weight, Dimensions
        </p>
    </div>
</div>

<?php
$pageContent = ob_get_clean();

require_once 'template.php';
?>