<?php
$pageTitle = 'Dashboard Overview';

// Fetch dashboard data
require_once 'config.php';
$totalProducts = $pdo->query("SELECT COUNT(*) FROM products")->fetchColumn();
$totalValue = $pdo->query("SELECT SUM(price * stock_quantity) FROM products")->fetchColumn();
$lowStockProducts = $pdo->query("SELECT COUNT(*) FROM products WHERE stock_quantity < 10")->fetchColumn();
$latestProducts = $pdo->query("SELECT * FROM products ORDER BY created_at DESC LIMIT 5")->fetchAll();
$totalQRScans = $pdo->query("SELECT COUNT(*) FROM qr_scans")->fetchColumn();

// Fetch monthly sales and QR scan data
$monthlySalesAndScans = $pdo->query("
    SELECT 
        DATE_FORMAT(p.created_at, '%Y-%m') as month, 
        SUM(p.price * p.stock_quantity) as total_sales,
        COUNT(q.id) as qr_scans
    FROM 
        products p
    LEFT JOIN 
        qr_scans q ON DATE_FORMAT(p.created_at, '%Y-%m') = DATE_FORMAT(q.scan_time, '%Y-%m')
    GROUP BY 
        DATE_FORMAT(p.created_at, '%Y-%m')
    ORDER BY 
        month DESC 
    LIMIT 6
")->fetchAll(PDO::FETCH_ASSOC);

$months = array_column(array_reverse($monthlySalesAndScans), 'month');
$salesData = array_column(array_reverse($monthlySalesAndScans), 'total_sales');
$scanData = array_column(array_reverse($monthlySalesAndScans), 'qr_scans');

// Check if a logo file exists
$logoFile = 'uploads/company_logo.png';
$logoExists = file_exists($logoFile);

// Handle logo upload
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_FILES['logo'])) {
    $uploadDir = 'uploads/';
    $uploadFile = $uploadDir . 'company_logo.png';
    
    if (move_uploaded_file($_FILES['logo']['tmp_name'], $uploadFile)) {
        $logoExists = true;
        $uploadMessage = "Logo uploaded successfully.";
    } else {
        $uploadMessage = "Failed to upload logo.";
    }
}

// Start output buffering
ob_start();
?>

<!-- Dashboard content -->
<div class="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-5 gap-6">
    <!-- Stat cards -->
    <div class="bg-white p-6 rounded-lg shadow-md">
        <h3 class="text-lg font-semibold mb-2 text-gray-700">Total Products</h3>
        <p class="text-3xl font-bold text-orange-500"><?php echo $totalProducts; ?></p>
    </div>
    <div class="bg-white p-6 rounded-lg shadow-md">
        <h3 class="text-lg font-semibold mb-2 text-gray-700">Total Inventory Value</h3>
        <p class="text-3xl font-bold text-orange-500">$<?php echo number_format($totalValue, 2); ?></p>
    </div>
    <div class="bg-white p-6 rounded-lg shadow-md">
        <h3 class="text-lg font-semibold mb-2 text-gray-700">Low Stock Products</h3>
        <p class="text-3xl font-bold text-orange-500"><?php echo $lowStockProducts; ?></p>
    </div>
    <div class="bg-white p-6 rounded-lg shadow-md">
        <h3 class="text-lg font-semibold mb-2 text-gray-700">New Products (30 days)</h3>
        <p class="text-3xl font-bold text-orange-500"><?php echo count($latestProducts); ?></p>
    </div>
    <div class="bg-white p-6 rounded-lg shadow-md">
        <h3 class="text-lg font-semibold mb-2 text-gray-700">Total QR Scans</h3>
        <p class="text-3xl font-bold text-orange-500"><?php echo $totalQRScans; ?></p>
    </div>

    <!-- Sales and QR Scans chart -->
    <div class="col-span-1 md:col-span-2 lg:col-span-3 bg-white p-6 rounded-lg shadow-md">
        <h3 class="text-lg font-semibold mb-4 text-gray-700">Monthly Sales and QR Scans</h3>
        <canvas id="salesScanChart"></canvas>
    </div>

    <!-- Latest products table -->
    <div class="col-span-1 md:col-span-2 lg:col-span-2 bg-white p-6 rounded-lg shadow-md">
        <h3 class="text-lg font-semibold mb-4 text-gray-700">Latest Products</h3>
        <div class="overflow-x-auto">
            <table class="w-full">
                <thead>
                    <tr class="bg-gray-100">
                        <th class="text-left py-2 px-4 font-semibold text-gray-600">Name</th>
                        <th class="text-left py-2 px-4 font-semibold text-gray-600">SKU</th>
                        <th class="text-left py-2 px-4 font-semibold text-gray-600">Price</th>
                        <th class="text-left py-2 px-4 font-semibold text-gray-600">Stock</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($latestProducts as $product): ?>
                    <tr class="border-b border-gray-200">
                        <td class="py-2 px-4"><?php echo htmlspecialchars($product['name']); ?></td>
                        <td class="py-2 px-4"><?php echo htmlspecialchars($product['sku']); ?></td>
                        <td class="py-2 px-4">$<?php echo number_format($product['price'], 2); ?></td>
                        <td class="py-2 px-4"><?php echo $product['stock_quantity']; ?></td>
                    </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>

    <!-- QR Code Logo Management -->
    <div class="col-span-1 md:col-span-2 lg:col-span-5 bg-white p-6 rounded-lg shadow-md">
        <h3 class="text-lg font-semibold mb-4 text-gray-700">QR Code Logo Management</h3>
        <?php if (isset($uploadMessage)): ?>
            <div class="bg-blue-100 border-l-4 border-blue-500 text-blue-700 p-4 mb-4" role="alert">
                <p><?php echo $uploadMessage; ?></p>
            </div>
        <?php endif; ?>
        <?php if ($logoExists): ?>
            <div class="mb-4">
                <p class="mb-2">Current Logo:</p>
                <img src="<?php echo $logoFile; ?>" alt="Company Logo" class="max-w-xs">
            </div>
        <?php endif; ?>
        <form action="" method="POST" enctype="multipart/form-data" class="mb-4">
            <div class="mb-4">
                <label for="logo" class="block text-gray-700 text-sm font-bold mb-2">Upload New Logo:</label>
                <input type="file" name="logo" id="logo" accept="image/*" class="shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline">
            </div>
            <button type="submit" class="bg-orange-500 hover:bg-orange-700 text-white font-bold py-2 px-4 rounded focus:outline-none focus:shadow-outline">
                Upload Logo
            </button>
        </form>
    </div>
</div>

<?php
$pageContent = ob_get_clean();

// Scripts for this page
ob_start();
?>
<script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
<script>
    // Sales and QR Scans chart
    const ctx = document.getElementById('salesScanChart').getContext('2d');
    new Chart(ctx, {
        type: 'bar',
        data: {
            labels: <?php echo json_encode($months); ?>,
            datasets: [{
                label: 'Monthly Sales',
                data: <?php echo json_encode($salesData); ?>,
                backgroundColor: 'rgba(246, 173, 85, 0.6)',
                borderColor: 'rgb(246, 173, 85)',
                borderWidth: 1,
                yAxisID: 'y-axis-1'
            }, {
                label: 'QR Scans',
                data: <?php echo json_encode($scanData); ?>,
                backgroundColor: 'rgba(75, 192, 192, 0.6)',
                borderColor: 'rgb(75, 192, 192)',
                borderWidth: 1,
                yAxisID: 'y-axis-2'
            }]
        },
        options: {
            responsive: true,
            scales: {
                'y-axis-1': {
                    type: 'linear',
                    position: 'left',
                    beginAtZero: true,
                    ticks: {
                        callback: function(value, index, values) {
                            return '$' + value.toLocaleString();
                        }
                    }
                },
                'y-axis-2': {
                    type: 'linear',
                    position: 'right',
                    beginAtZero: true,
                    grid: {
                        drawOnChartArea: false
                    }
                }
            }
        }
    });
</script>
<?php
$pageScripts = ob_get_clean();

// Include the template
require_once 'template.php';
?>