<?php
$pageTitle = 'Edit Product';
require_once 'config.php';

$message = '';

if (!isset($_GET['id']) || !is_numeric($_GET['id'])) {
    header("Location: product_list.php");
    exit();
}

$product_id = $_GET['id'];

// Fetch all categories
$stmt = $pdo->query("SELECT id, name FROM categories ORDER BY name");
$categories = $stmt->fetchAll();

// Fetch the product
$stmt = $pdo->prepare("SELECT * FROM products WHERE id = ?");
$stmt->execute([$product_id]);
$product = $stmt->fetch();

if (!$product) {
    header("Location: product_list.php");
    exit();
}

if ($_SERVER["REQUEST_METHOD"] == "POST") {
    $name = $_POST['name'] ?? '';
    $description = $_POST['description'] ?? '';
    $sku = $_POST['sku'] ?? '';
    $price = $_POST['price'] ?? '';
    $stock_quantity = $_POST['stock_quantity'] ?? '';
    $category_id = $_POST['category_id'] ?? null;
    $brand = $_POST['brand'] ?? '';
    $weight = $_POST['weight'] ?? '';
    $dimensions = $_POST['dimensions'] ?? '';

    // Handle logo upload
    $logo = $product['logo'];
    if (isset($_FILES['logo']) && $_FILES['logo']['error'] == 0) {
        $allowed_types = ['image/jpeg', 'image/png', 'image/gif'];
        $max_size = 2 * 1024 * 1024; // 2MB

        $file_type = $_FILES['logo']['type'];
        $file_size = $_FILES['logo']['size'];

        if (!in_array($file_type, $allowed_types)) {
            $message = "Invalid logo file type. Allowed types are JPEG, PNG, and GIF.";
        } elseif ($file_size > $max_size) {
            $message = "Logo file size exceeds the maximum limit of 2MB.";
        } else {
            $new_logo = uniqid() . '_' . $_FILES['logo']['name'];
            $logo_upload_path = 'uploads/logos/' . $new_logo;
            if (move_uploaded_file($_FILES['logo']['tmp_name'], $logo_upload_path)) {
                // Delete old logo if exists
                if ($logo && file_exists('uploads/logos/' . $logo)) {
                    unlink('uploads/logos/' . $logo);
                }
                $logo = $new_logo;
            } else {
                $message = "Failed to upload the logo.";
            }
        }
    }

    // Handle product file upload
    $product_file = $product['product_file'];
    $product_file_type = $product['product_file_type'];
    if (isset($_FILES['product_file']) && $_FILES['product_file']['error'] == 0) {
        $allowed_types = ['image/jpeg', 'image/png', 'image/gif', 'application/pdf', 'application/msword', 'application/vnd.openxmlformats-officedocument.wordprocessingml.document', 'application/vnd.ms-excel', 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet'];
        $max_size = 10 * 1024 * 1024; // 10MB

        $file_type = $_FILES['product_file']['type'];
        $file_size = $_FILES['product_file']['size'];

        if (!in_array($file_type, $allowed_types)) {
            $message = "Invalid file type. Allowed types are JPEG, PNG, GIF, PDF, DOC, DOCX, XLS, and XLSX.";
        } elseif ($file_size > $max_size) {
            $message = "File size exceeds the maximum limit of 10MB.";
        } else {
            $new_product_file = uniqid() . '_' . $_FILES['product_file']['name'];
            $file_upload_path = 'uploads/product_files/' . $new_product_file;
            if (move_uploaded_file($_FILES['product_file']['tmp_name'], $file_upload_path)) {
                // Delete old file if exists
                if ($product_file && file_exists('uploads/product_files/' . $product_file)) {
                    unlink('uploads/product_files/' . $product_file);
                }
                $product_file = $new_product_file;
                $product_file_type = $file_type;
            } else {
                $message = "Failed to upload the product file.";
            }
        }
    }

    if (empty($message)) {
        $sql = "UPDATE products SET name = :name, description = :description, sku = :sku, 
                price = :price, stock_quantity = :stock_quantity, category_id = :category_id, 
                brand = :brand, weight = :weight, dimensions = :dimensions, 
                logo = :logo, product_file = :product_file, product_file_type = :product_file_type 
                WHERE id = :id";
        
        try {
            $stmt = $pdo->prepare($sql);
            $stmt->execute([
                ':name' => $name,
                ':description' => $description,
                ':sku' => $sku,
                ':price' => $price,
                ':stock_quantity' => $stock_quantity,
                ':category_id' => $category_id,
                ':brand' => $brand,
                ':weight' => $weight,
                ':dimensions' => $dimensions,
                ':logo' => $logo,
                ':product_file' => $product_file,
                ':product_file_type' => $product_file_type,
                ':id' => $product_id
            ]);
            $message = "Product updated successfully!";
            
            // Refresh product data after update
            $stmt = $pdo->prepare("SELECT * FROM products WHERE id = ?");
            $stmt->execute([$product_id]);
            $product = $stmt->fetch();
        } catch(PDOException $e) {
            $message = "Error: " . $e->getMessage();
        }
    }
}

ob_start();
?>

<div class="bg-white p-6 rounded-lg shadow-md">
    <h3 class="text-lg font-semibold text-gray-700 mb-4">Edit Product</h3>
    
    <?php if ($message): ?>
        <div class="bg-blue-100 border-l-4 border-blue-500 text-blue-700 p-4 mb-4" role="alert">
            <p><?php echo $message; ?></p>
        </div>
    <?php endif; ?>

    <form action="" method="POST" enctype="multipart/form-data">
        <div class="mb-4">
            <label for="name" class="block text-gray-700 text-sm font-bold mb-2">Name:</label>
            <input type="text" id="name" name="name" value="<?php echo htmlspecialchars($product['name']); ?>" required class="shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline">
        </div>

        <div class="mb-4">
            <label for="description" class="block text-gray-700 text-sm font-bold mb-2">Description:</label>
            <textarea id="description" name="description" class="shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline" rows="3"><?php echo htmlspecialchars($product['description']); ?></textarea>
        </div>

        <div class="mb-4">
            <label for="sku" class="block text-gray-700 text-sm font-bold mb-2">SKU:</label>
            <input type="text" id="sku" name="sku" value="<?php echo htmlspecialchars($product['sku']); ?>" required class="shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline">
        </div>

        <div class="mb-4">
            <label for="price" class="block text-gray-700 text-sm font-bold mb-2">Price:</label>
            <input type="number" id="price" name="price" step="0.01" value="<?php echo $product['price']; ?>" required class="shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline">
        </div>

        <div class="mb-4">
            <label for="stock_quantity" class="block text-gray-700 text-sm font-bold mb-2">Stock Quantity:</label>
            <input type="number" id="stock_quantity" name="stock_quantity" value="<?php echo $product['stock_quantity']; ?>" required class="shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline">
        </div>

        <div class="mb-4">
            <label for="category_id" class="block text-gray-700 text-sm font-bold mb-2">Category:</label>
            <select id="category_id" name="category_id" class="shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline">
                <option value="">Select a category</option>
                <?php foreach ($categories as $category): ?>
                    <option value="<?php echo $category['id']; ?>" <?php echo ($category['id'] == $product['category_id']) ? 'selected' : ''; ?>><?php echo htmlspecialchars($category['name']); ?></option>
                <?php endforeach; ?>
            </select>
        </div>

        <div class="mb-4">
            <label for="brand" class="block text-gray-700 text-sm font-bold mb-2">Brand:</label>
            <input type="text" id="brand" name="brand" value="<?php echo htmlspecialchars($product['brand']); ?>" class="shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline">
        </div>

        <div class="mb-4">
            <label for="weight" class="block text-gray-700 text-sm font-bold mb-2">Weight:</label>
            <input type="number" id="weight" name="weight" step="0.01" value="<?php echo $product['weight']; ?>" class="shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline">
        </div>

        <div class="mb-4">
            <label for="dimensions" class="block text-gray-700 text-sm font-bold mb-2">Dimensions:</label>
            <input type="text" id="dimensions" name="dimensions" value="<?php echo htmlspecialchars($product['dimensions']); ?>" placeholder="L x W x H" class="shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline">
        </div>

        <div class="mb-4">
            <label for="logo" class="block text-gray-700 text-sm font-bold mb-2">Product Logo (for QR Code):</label>
            <input type="file" id="logo" name="logo" accept="image/*" class="shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline">
            <p class="text-sm text-gray-600 mt-1">Max file size: 2MB. Allowed formats: JPEG, PNG, GIF.</p>
            <?php if ($product['logo']): ?>
                <p class="text-sm text-gray-600 mt-1">Current logo: <?php echo htmlspecialchars($product['logo']); ?></p>
            <?php endif; ?>
        </div>

        <div class="mb-4">
            <label for="product_file" class="block text-gray-700 text-sm font-bold mb-2">Product File:</label>
            <input type="file" id="product_file" name="product_file" class="shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline">
            <p class="text-sm text-gray-600 mt-1">Max file size: 10MB. Allowed formats: JPEG, PNG, GIF, PDF, DOC, DOCX, XLS, XLSX.</p>
            <?php if ($product['product_file']): ?>
                <p class="text-sm text-gray-600 mt-1">Current file: <?php echo htmlspecialchars($product['product_file']); ?></p>
            <?php endif; ?>
        </div>

        <div class="flex items-center justify-between">
            <button type="submit" class="bg-orange-500 hover:bg-orange-700 text-white font-bold py-2 px-4 rounded focus:outline-none focus:shadow-outline">
                Update Product
            </button>
            <a href="product_list.php" class="inline-block align-baseline font-bold text-sm text-orange-500 hover:text-orange-800">
                Cancel
            </a>
        </div>
    </form>
</div>

<?php
$pageContent = ob_get_clean();
require_once 'template.php';
?>