<?php
$pageTitle = 'Export Products';
require_once 'config.php';
require 'vendor/autoload.php';

use PhpOffice\PhpSpreadsheet\Spreadsheet;
use PhpOffice\PhpSpreadsheet\Writer\Csv;

$available_fields = [
    'name' => 'Product Name',
    'description' => 'Description',
    'sku' => 'SKU',
    'price' => 'Price',
    'stock_quantity' => 'Stock Quantity',
    'category_name' => 'Category',
    'brand' => 'Brand',
    'weight' => 'Weight',
    'dimensions' => 'Dimensions',
    'file_name' => 'File Name',
    'file_type' => 'File Type',
    'file_size' => 'File Size',
    'logo' => 'Logo File Name'
];

if (isset($_POST['export']) && !empty($_POST['fields'])) {
    $selected_fields = $_POST['fields'];
    
    // Construct the SQL query based on selected fields
    $field_sql = implode(', ', array_map(function($field) {
        return $field === 'category_name' ? 'c.name as category_name' : "p.$field";
    }, $selected_fields));

    $sql = "SELECT $field_sql FROM products p LEFT JOIN categories c ON p.category_id = c.id";
    $stmt = $pdo->query($sql);
    $products = $stmt->fetchAll(PDO::FETCH_ASSOC);

    if (!empty($products)) {
        $spreadsheet = new Spreadsheet();
        $sheet = $spreadsheet->getActiveSheet();

        // Add header row
        $headers = array_intersect_key($available_fields, array_flip($selected_fields));
        $sheet->fromArray([array_values($headers)], NULL, 'A1');

        // Add product data
        $sheet->fromArray($products, NULL, 'A2');

        $writer = new Csv($spreadsheet);

        header('Content-Type: text/csv');
        header('Content-Disposition: attachment;filename="products_export_' . date('Y-m-d') . '.csv"');
        header('Cache-Control: max-age=0');

        $writer->save('php://output');
        exit;
    }
}

ob_start();
?>

<div class="bg-white p-6 rounded-lg shadow-md">
    <h3 class="text-lg font-semibold text-gray-700 mb-4">Export Products</h3>
    
    <form action="" method="POST">
        <div class="mb-4">
            <label class="block text-gray-700 text-sm font-bold mb-2">Select fields to export:</label>
            <?php foreach ($available_fields as $field => $label): ?>
                <div class="mb-2">
                    <label class="inline-flex items-center">
                        <input type="checkbox" class="form-checkbox" name="fields[]" value="<?php echo $field; ?>" 
                               <?php echo ($field === 'name' || $field === 'sku') ? 'checked' : ''; ?>>
                        <span class="ml-2"><?php echo $label; ?></span>
                    </label>
                </div>
            <?php endforeach; ?>
        </div>
        
        <button type="submit" name="export" class="bg-orange-500 hover:bg-orange-700 text-white font-bold py-2 px-4 rounded focus:outline-none focus:shadow-outline">
            Export Selected Fields to CSV
        </button>
    </form>
    
    <div class="mt-4">
        <p class="text-sm text-gray-600">
            Select the fields you want to include in your CSV export. At least one field must be selected.
        </p>
    </div>
</div>

<?php
$pageContent = ob_get_clean();

require_once 'template.php';
?>