<?php
require_once 'config.php';
require_once 'vendor/autoload.php';

use Endroid\QrCode\QrCode;
use Endroid\QrCode\Writer\PngWriter;
use Endroid\QrCode\Logo\Logo;

if (!isset($_GET['id']) || !is_numeric($_GET['id'])) {
    die("Invalid product ID");
}

$product_id = $_GET['id'];
$download = isset($_GET['download']);
$print = isset($_GET['print']);
$add_logo = isset($_GET['logo']);

// Fetch the product
$stmt = $pdo->prepare("SELECT * FROM products WHERE id = ?");
$stmt->execute([$product_id]);
$product = $stmt->fetch();

if (!$product) {
    die("Product not found");
}

// Generate QR code
$url = "http://" . $_SERVER['HTTP_HOST'] . dirname($_SERVER['PHP_SELF']) . "/public_product_view.php?id=" . $product_id;

$qrCode = QrCode::create($url)
    ->setSize(300)
    ->setMargin(10);

$writer = new PngWriter();

// Add logo if requested and file exists
$logo = null;
if ($add_logo && !empty($product['logo'])) {
    $logo_path = __DIR__ . '/uploads/logos/' . $product['logo'];
    if (file_exists($logo_path)) {
        $logo = Logo::create($logo_path)
            ->setResizeToWidth(50);
    }
}

$result = $writer->write($qrCode, $logo);

// Generate filename
$filename = preg_replace('/[^A-Za-z0-9\-]/', '', $product['name']) . '-' . $product['sku'] . '.png';

if ($print) {
    // Output print-friendly page
    echo '<!DOCTYPE html>
    <html>
    <head>
        <title>Print QR Code for ' . htmlspecialchars($product['name']) . '</title>
        <style>
            body { display: flex; flex-direction: column; justify-content: center; align-items: center; height: 100vh; margin: 0; font-family: Arial, sans-serif; }
            img { max-width: 100%; height: auto; margin-bottom: 20px; }
            h1 { font-size: 18px; margin-bottom: 10px; }
        </style>
    </head>
    <body>
        <h1>' . htmlspecialchars($product['name']) . ' - ' . htmlspecialchars($product['sku']) . '</h1>
        <img src="data:' . $result->getMimeType() . ';base64,' . base64_encode($result->getString()) . '">
        <script>window.onload = function() { window.print(); }</script>
    </body>
    </html>';
    exit;
}

// Set headers for download or display
header("Content-Type: " . $result->getMimeType());
if ($download) {
    header('Content-Disposition: attachment; filename="' . $filename . '"');
} else {
    header('Content-Disposition: inline; filename="' . $filename . '"');
}

// Output the QR code
echo $result->getString();

// Record the QR code generation in the database
$stmt = $pdo->prepare("INSERT INTO qr_scans (product_id) VALUES (?)");
$stmt->execute([$product_id]);
?>