<?php
if (session_status() == PHP_SESSION_NONE) {
    session_start();
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo $pageTitle ?? 'Product Management System'; ?></title>
    <style>
        :root {
            --brand-color: #f36f21;
            --brand-color-dark: #d85a0f;
            --text-color: #333;
            --bg-color: #f8f9fa;
            --border-color: #e0e0e0;
        }
        * {
            box-sizing: border-box;
        }
        body {
            font-family: Arial, sans-serif;
            margin: 0;
            padding: 0;
            color: var(--text-color);
            line-height: 1.6;
        }
        .header {
            background-color: var(--brand-color);
            padding: 15px 20px;
            display: flex;
            justify-content: space-between;
            align-items: center;
            box-shadow: 0 2px 4px rgba(0,0,0,0.1);
        }
        .header h1 {
            margin: 0;
            font-size: 24px;
            color: white;
        }
        .nav-buttons {
            display: flex;
            gap: 10px;
        }
        .nav-buttons a {
            text-decoration: none;
            color: var(--brand-color);
            background-color: white;
            padding: 8px 15px;
            border-radius: 5px;
            font-size: 14px;
            font-weight: bold;
            transition: background-color 0.3s, color 0.3s;
        }
        .nav-buttons a:hover {
            background-color: var(--brand-color-dark);
            color: white;
        }
        .content {
            padding: 20px;
            max-width: 1200px;
            margin: 0 auto;
        }
        .btn {
            display: inline-block;
            padding: 10px 20px;
            background-color: var(--brand-color);
            color: white;
            text-decoration: none;
            border-radius: 5px;
            transition: background-color 0.3s;
            border: none;
            cursor: pointer;
            font-size: 16px;
        }
        .btn:hover {
            background-color: var(--brand-color-dark);
        }
        table {
            border-collapse: collapse;
            width: 100%;
            margin-top: 20px;
        }
        th, td {
            border: 1px solid var(--border-color);
            padding: 12px;
            text-align: left;
        }
        th {
            background-color: var(--bg-color);
            font-weight: bold;
        }
        tr:nth-child(even) {
            background-color: var(--bg-color);
        }
        .message {
            padding: 10px;
            margin-bottom: 20px;
            border-radius: 5px;
            font-weight: bold;
        }
        .message.success {
            background-color: #d4edda;
            border: 1px solid #c3e6cb;
            color: #155724;
        }
        .message.error {
            background-color: #f8d7da;
            border: 1px solid #f5c6cb;
            color: #721c24;
        }
        form {
            background-color: white;
            padding: 20px;
            border-radius: 5px;
            box-shadow: 0 0 10px rgba(0,0,0,0.1);
        }
        label {
            display: block;
            margin-top: 10px;
            font-weight: bold;
        }
        input[type="text"],
        input[type="number"],
        input[type="password"],
        textarea,
        select {
            width: 100%;
            padding: 8px;
            margin-top: 5px;
            border: 1px solid var(--border-color);
            border-radius: 4px;
            font-size: 16px;
        }
        input[type="submit"] {
            margin-top: 20px;
        }
        .dashboard-cards {
            display: flex;
            justify-content: space-between;
            margin-bottom: 20px;
        }
        .dashboard-card {
            background-color: var(--brand-color);
            color: white;
            padding: 20px;
            border-radius: 5px;
            width: 30%;
        }
        .dashboard-card h3 {
            margin-top: 0;
            font-size: 18px;
        }
        .dashboard-card p {
            font-size: 24px;
            font-weight: bold;
            margin: 10px 0 0;
        }
    </style>
</head>
<body>
    <div class="header">
        <h1><?php echo $pageTitle ?? 'Product Management System'; ?></h1>
        <div class="nav-buttons">
            <a href="dashboard.php">Dashboard</a>
            <a href="product_list.php">Products</a>
            <?php if (isset($_SESSION['user_id'])): ?>
                <a href="logout.php">Logout</a>
            <?php else: ?>
                <a href="login.php">Login</a>
            <?php endif; ?>
        </div>
    </div>
    <div class="content">
    <?php
    if (isset($message)) {
        $messageClass = strpos($message, 'Error') !== false ? 'error' : 'success';
        echo "<div class='message {$messageClass}'>" . htmlspecialchars($message) . "</div>";
    }
    ?>