<?php
$pageTitle = 'Product Details';
require_once 'config.php';

// Check if a product ID is provided
if (!isset($_GET['id']) || !is_numeric($_GET['id'])) {
    header("Location: product_list.php");
    exit();
}

$product_id = $_GET['id'];

// Fetch the product
$stmt = $pdo->prepare("SELECT p.*, c.name AS category_name FROM products p 
                       LEFT JOIN categories c ON p.category_id = c.id 
                       WHERE p.id = ?");
$stmt->execute([$product_id]);
$product = $stmt->fetch();

if (!$product) {
    header("Location: product_list.php");
    exit();
}

// Record the QR code scan
$stmt = $pdo->prepare("INSERT INTO qr_scans (product_id) VALUES (?)");
$stmt->execute([$product_id]);

ob_start();
?>

<div class="bg-white p-6 rounded-lg shadow-md">
    <h1 class="text-2xl font-bold text-gray-800 mb-4"><?php echo htmlspecialchars($product['name']); ?></h1>
    
    <div class="grid grid-cols-1 md:grid-cols-2 gap-6">
        <div>
            <p class="text-gray-600 mb-2"><strong>SKU:</strong> <?php echo htmlspecialchars($product['sku']); ?></p>
            <p class="text-gray-600 mb-2"><strong>Price:</strong> $<?php echo number_format($product['price'], 2); ?></p>
            <p class="text-gray-600 mb-2"><strong>Stock Quantity:</strong> <?php echo $product['stock_quantity']; ?></p>
            <p class="text-gray-600 mb-2"><strong>Category:</strong> <?php echo htmlspecialchars($product['category_name']); ?></p>
            <p class="text-gray-600 mb-2"><strong>Brand:</strong> <?php echo htmlspecialchars($product['brand']); ?></p>
            <p class="text-gray-600 mb-2"><strong>Weight:</strong> <?php echo $product['weight']; ?></p>
            <p class="text-gray-600 mb-2"><strong>Dimensions:</strong> <?php echo htmlspecialchars($product['dimensions']); ?></p>
            
            <?php if ($product['file_name']): ?>
                <p class="text-gray-600 mb-2">
                    <strong>Product File:</strong> 
                    <a href="uploads/<?php echo urlencode($product['file_name']); ?>" target="_blank" class="text-blue-500 hover:underline">
                        <?php echo htmlspecialchars($product['file_name']); ?>
                    </a>
                </p>
            <?php endif; ?>
        </div>
        
        <div>
            <h2 class="text-xl font-semibold text-gray-700 mb-2">Description</h2>
            <p class="text-gray-600"><?php echo nl2br(htmlspecialchars($product['description'])); ?></p>
        </div>
    </div>

    <div class="mt-6">
        <a href="product_list.php" class="bg-orange-500 hover:bg-orange-700 text-white font-bold py-2 px-4 rounded focus:outline-none focus:shadow-outline">
            Back to Product List
        </a>
    </div>
</div>

<?php
$pageContent = ob_get_clean();
require_once 'template.php';
?>