<?php
$pageTitle = 'Product List';
require_once 'config.php';

// Fetch products with category names
$stmt = $pdo->query("SELECT p.*, c.name as category_name FROM products p LEFT JOIN categories c ON p.category_id = c.id ORDER BY p.created_at DESC");
$products = $stmt->fetchAll();

ob_start();
?>

<div class="bg-white p-6 rounded-lg shadow-md">
    <div class="flex justify-between items-center mb-4">
        <h3 class="text-lg font-semibold text-gray-700">All Products</h3>
        <a href="add_product.php" class="bg-orange-500 text-white px-4 py-2 rounded hover:bg-orange-600">Add New Product</a>
    </div>
    <div class="overflow-x-auto">
        <table class="w-full">
            <thead>
                <tr class="bg-gray-100">
                    <th class="text-left py-2 px-4 font-semibold text-gray-600">Name</th>
                    <th class="text-left py-2 px-4 font-semibold text-gray-600">SKU</th>
                    <th class="text-left py-2 px-4 font-semibold text-gray-600">Price</th>
                    <th class="text-left py-2 px-4 font-semibold text-gray-600">Stock</th>
                    <th class="text-left py-2 px-4 font-semibold text-gray-600">Category</th>
                    <th class="text-left py-2 px-4 font-semibold text-gray-600">Actions</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($products as $product): ?>
                <tr class="border-b border-gray-200">
                    <td class="py-2 px-4"><?php echo htmlspecialchars($product['name']); ?></td>
                    <td class="py-2 px-4"><?php echo htmlspecialchars($product['sku']); ?></td>
                    <td class="py-2 px-4">$<?php echo number_format($product['price'], 2); ?></td>
                    <td class="py-2 px-4"><?php echo $product['stock_quantity']; ?></td>
                    <td class="py-2 px-4"><?php echo htmlspecialchars($product['category_name'] ?? 'Uncategorized'); ?></td>
                    <td class="py-2 px-4">
                        <a href="edit_product.php?id=<?php echo $product['id']; ?>" class="text-blue-500 hover:text-blue-700 mr-2">Edit</a>
                        <a href="delete_product.php?id=<?php echo $product['id']; ?>" class="text-red-500 hover:text-red-700 mr-2" onclick="return confirm('Are you sure you want to delete this product?')">Delete</a>
                        <a href="generate_qr.php?id=<?php echo $product['id']; ?>&format=png" class="text-green-500 hover:text-green-700 mr-2" target="_blank">QR Code</a>
                        <a href="generate_qr.php?id=<?php echo $product['id']; ?>&print=1" class="text-purple-500 hover:text-purple-700" onclick="window.open(this.href, 'printWindow', 'width=800,height=600'); return false;">Print QR</a>
                    </td>
                </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
    </div>
</div>

<?php
$pageContent = ob_get_clean();
require_once 'template.php';
?>