<?php
require_once 'config.php';

// Check if product ID is provided
if (!isset($_GET['id']) || !is_numeric($_GET['id'])) {
    die("Invalid product ID.");
}

$product_id = $_GET['id'];

// Fetch product from the database
$stmt = $pdo->prepare("SELECT p.*, c.name as category_name FROM products p LEFT JOIN categories c ON p.category_id = c.id WHERE p.id = ?");
$stmt->execute([$product_id]);
$product = $stmt->fetch(PDO::FETCH_ASSOC);

// If product not found, show error
if (!$product) {
    die("Product not found.");
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo htmlspecialchars($product['name']); ?> - Product Details</title>
    <script src="https://cdn.tailwindcss.com"></script>
</head>
<body class="bg-gray-100">
    <div class="container mx-auto px-4 py-8">
        <div class="bg-white shadow-md rounded-lg p-6">
            <h1 class="text-2xl font-bold text-gray-800 mb-4"><?php echo htmlspecialchars($product['name']); ?></h1>
            
            <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
                <div>
                    <p class="text-gray-600"><span class="font-semibold">SKU:</span> <?php echo htmlspecialchars($product['sku']); ?></p>
                    <p class="text-gray-600"><span class="font-semibold">Price:</span> $<?php echo number_format($product['price'], 2); ?></p>
                    <p class="text-gray-600"><span class="font-semibold">Brand:</span> <?php echo htmlspecialchars($product['brand']); ?></p>
                    <p class="text-gray-600"><span class="font-semibold">Category:</span> <?php echo htmlspecialchars($product['category_name']); ?></p>
                </div>
                <div>
                    <p class="text-gray-600"><span class="font-semibold">Weight:</span> <?php echo $product['weight']; ?> kg</p>
                    <p class="text-gray-600"><span class="font-semibold">Dimensions:</span> <?php echo htmlspecialchars($product['dimensions']); ?></p>
                    <p class="text-gray-600"><span class="font-semibold">In Stock:</span> <?php echo $product['stock_quantity']; ?></p>
                </div>
            </div>
            
            <div class="mt-4">
                <h2 class="text-xl font-semibold text-gray-800 mb-2">Description</h2>
                <p class="text-gray-600"><?php echo nl2br(htmlspecialchars($product['description'])); ?></p>
            </div>

            <?php if ($product['product_file']): ?>
                <div class="mt-4">
                    <h2 class="text-xl font-semibold text-gray-800 mb-2">Product File</h2>
                    <?php
                    $file_path = 'uploads/product_files/' . $product['product_file'];
                    $file_extension = pathinfo($product['product_file'], PATHINFO_EXTENSION);
                    
                    if (in_array($product['product_file_type'], ['image/jpeg', 'image/png', 'image/gif'])): ?>
                        <img src="<?php echo $file_path; ?>" alt="Product Image" class="max-w-full h-auto rounded-lg shadow-md">
                    <?php else: ?>
                        <a href="<?php echo $file_path; ?>" download class="inline-block bg-blue-500 hover:bg-blue-700 text-white font-bold py-2 px-4 rounded">
                            Download <?php echo strtoupper($file_extension); ?> File
                        </a>
                    <?php endif; ?>
                </div>
            <?php endif; ?>
        </div>
    </div>
</body>
</html>