<?php
$pageTitle = 'Search Results';

require_once 'config.php';

// Get the search query
$query = isset($_GET['query']) ? trim($_GET['query']) : '';

// Perform the search
$searchResults = [];
if (!empty($query)) {
    $stmt = $pdo->prepare("SELECT * FROM products WHERE name LIKE :query1 OR description LIKE :query2 OR sku LIKE :query3");
    $queryParam = "%$query%";
    $stmt->execute([
        'query1' => $queryParam,
        'query2' => $queryParam,
        'query3' => $queryParam
    ]);
    $searchResults = $stmt->fetchAll(PDO::FETCH_ASSOC);
}

// Start output buffering
ob_start();
?>

<div class="bg-white p-6 rounded-lg shadow-md">
    <h3 class="text-lg font-semibold text-gray-700 mb-4">Search Results for "<?php echo htmlspecialchars($query); ?>"</h3>
    
    <?php if (empty($searchResults)): ?>
        <p class="text-gray-600">No products found matching your search.</p>
    <?php else: ?>
        <div class="overflow-x-auto">
            <table class="w-full">
                <thead>
                    <tr class="bg-gray-100">
                        <th class="text-left py-2 px-4 font-semibold text-gray-600">Name</th>
                        <th class="text-left py-2 px-4 font-semibold text-gray-600">SKU</th>
                        <th class="text-left py-2 px-4 font-semibold text-gray-600">Price</th>
                        <th class="text-left py-2 px-4 font-semibold text-gray-600">Stock</th>
                        <th class="text-left py-2 px-4 font-semibold text-gray-600">Actions</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($searchResults as $product): ?>
                    <tr class="border-b border-gray-200">
                        <td class="py-2 px-4"><?php echo htmlspecialchars($product['name']); ?></td>
                        <td class="py-2 px-4"><?php echo htmlspecialchars($product['sku']); ?></td>
                        <td class="py-2 px-4">$<?php echo number_format($product['price'], 2); ?></td>
                        <td class="py-2 px-4"><?php echo $product['stock_quantity']; ?></td>
                        <td class="py-2 px-4">
                            <a href="edit_product.php?id=<?php echo $product['id']; ?>" class="text-blue-500 hover:text-blue-700 mr-2">Edit</a>
                            <a href="generate_qr.php?id=<?php echo $product['id']; ?>&format=png" class="text-green-500 hover:text-green-700 mr-2">QR Code</a>
                            <a href="delete_product.php?id=<?php echo $product['id']; ?>" class="text-red-500 hover:text-red-700" onclick="return confirm('Are you sure you want to delete this product?')">Delete</a>
                        </td>
                    </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    <?php endif; ?>
    
    <div class="mt-4">
        <a href="product_list.php" class="bg-gray-500 text-white px-4 py-2 rounded hover:bg-gray-600">Back to All Products</a>
    </div>
</div>

<?php
$pageContent = ob_get_clean();

require_once 'template.php';
?>