<?php
if (session_status() == PHP_SESSION_NONE) {
    session_start();
}
require_once 'config.php';

// Check if user is logged in
if (!isset($_SESSION['user_id'])) {
    header("Location: login.php");
    exit();
}

// Function to set active menu item
function setActive($currPage) {
    $pageName = basename($_SERVER['PHP_SELF']);
    return ($currPage == $pageName) ? 'bg-gray-800' : '';
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo $pageTitle ?? 'Product Management System'; ?></title>
    <script src="https://cdn.tailwindcss.com"></script>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.3/css/all.min.css" rel="stylesheet">
    <style>
        .sidebar-icon {
            width: 20px;
            display: inline-block;
            text-align: center;
        }
    </style>
</head>
<body class="bg-gray-100">
    <div class="flex">
        <!-- Sidebar -->
        <div class="w-64 bg-black min-h-screen p-4">
            <h1 class="text-white text-2xl font-bold mb-8">Product CMS</h1>
            <nav>
                <ul class="space-y-2">
                    <li><a href="dashboard.php" class="text-gray-300 hover:text-white flex items-center py-2 px-4 rounded transition duration-200 hover:bg-gray-800 <?php echo setActive('dashboard.php'); ?>">
                        <span class="sidebar-icon"><i class="fas fa-tachometer-alt"></i></span>
                        <span class="ml-2">Dashboard</span>
                    </a></li>
                    <li><a href="product_list.php" class="text-gray-300 hover:text-white flex items-center py-2 px-4 rounded transition duration-200 hover:bg-gray-800 <?php echo setActive('product_list.php'); ?>">
                        <span class="sidebar-icon"><i class="fas fa-box"></i></span>
                        <span class="ml-2">Products</span>
                    </a></li>
                    <li><a href="add_product.php" class="text-gray-300 hover:text-white flex items-center py-2 px-4 rounded transition duration-200 hover:bg-gray-800 <?php echo setActive('add_product.php'); ?>">
                        <span class="sidebar-icon"><i class="fas fa-plus"></i></span>
                        <span class="ml-2">Add Product</span>
                    </a></li>
                    <li><a href="category_list.php" class="text-gray-300 hover:text-white flex items-center py-2 px-4 rounded transition duration-200 hover:bg-gray-800 <?php echo setActive('category_list.php'); ?>">
                        <span class="sidebar-icon"><i class="fas fa-tags"></i></span>
                        <span class="ml-2">Categories</span>
                    </a></li>
                    <li><a href="bulk_upload.php" class="text-gray-300 hover:text-white flex items-center py-2 px-4 rounded transition duration-200 hover:bg-gray-800 <?php echo setActive('bulk_upload.php'); ?>">
                        <span class="sidebar-icon"><i class="fas fa-upload"></i></span>
                        <span class="ml-2">Bulk Upload</span>
                    </a></li>
                    <li><a href="export_products.php" class="text-gray-300 hover:text-white flex items-center py-2 px-4 rounded transition duration-200 hover:bg-gray-800 <?php echo setActive('export_products.php'); ?>">
                        <span class="sidebar-icon"><i class="fas fa-download"></i></span>
                        <span class="ml-2">Export Products</span>
                    </a></li>
                    <li class="mt-4">
                        <span class="text-gray-500 font-semibold text-xs uppercase">QR Codes</span>
                    </li>
                    <!-- <li><a href="generate_qr.php" class="text-gray-300 hover:text-white flex items-center py-2 px-4 rounded transition duration-200 hover:bg-gray-800 <?php echo setActive('generate_qr.php'); ?>">
                        <span class="sidebar-icon"><i class="fas fa-qrcode"></i></span>
                        <span class="ml-2">Generate Single QR</span>
                    </a></li> -->
                    <li><a href="bulk_qr_generate.php" class="text-gray-300 hover:text-white flex items-center py-2 px-4 rounded transition duration-200 hover:bg-gray-800 <?php echo setActive('bulk_qr_generate.php'); ?>">
                        <span class="sidebar-icon"><i class="fas fa-th"></i></span>
                        <span class="ml-2">Bulk QR Generation</span>
                    </a></li>
                    <li><a href="logout.php" class="text-gray-300 hover:text-white flex items-center py-2 px-4 rounded transition duration-200 hover:bg-gray-800">
                        <span class="sidebar-icon"><i class="fas fa-sign-out-alt"></i></span>
                        <span class="ml-2">Logout</span>
                    </a></li>
                </ul>
            </nav>
        </div>
        
        <!-- Main content -->
        <div class="flex-1 p-8">
            <!-- Header -->
            <header class="flex justify-between items-center mb-8">
                <h2 class="text-2xl font-bold text-gray-800"><?php echo $pageTitle ?? 'Page Title'; ?></h2>
                <div class="flex items-center">
                    <form action="search_results.php" method="GET" class="mr-4">
                        <input type="text" name="query" placeholder="Search products..." class="p-2 border border-gray-300 rounded-l-md focus:outline-none focus:ring-2 focus:ring-orange-500">
                        <button type="submit" class="bg-orange-500 text-white p-2 rounded-r-md hover:bg-orange-600 focus:outline-none focus:ring-2 focus:ring-orange-500">
                            <i class="fas fa-search"></i>
                        </button>
                    </form>
                    <img src="https://via.placeholder.com/40" alt="User Avatar" class="rounded-full">
                </div>
            </header>
            
            <!-- Page specific content will go here -->
            <?php echo $pageContent ?? ''; ?>
        </div>
    </div>

    <?php echo $pageScripts ?? ''; ?>
</body>
</html>