<?php
session_start();
require_once 'config.php';

// Check if user is logged in
if (!isset($_SESSION['user_id'])) {
    header("Location: login.php");
    exit();
}
$pageTitle = 'Prouct CMS'; // Change this for each page
require_once 'header.php';
// Check if product ID is provided
if (!isset($_GET['id']) || !is_numeric($_GET['id'])) {
    header("Location: product_list.php");
    exit();
}

$product_id = $_GET['id'];

// Fetch product from the database
$stmt = $pdo->prepare("SELECT * FROM products WHERE id = ?");
$stmt->execute([$product_id]);
$product = $stmt->fetch();

// If product not found, redirect to product list
if (!$product) {
    header("Location: product_list.php");
    exit();
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>View Product - <?php echo htmlspecialchars($product['name']); ?></title>
    <style>
        body {
            font-family: Arial, sans-serif;
            margin: 0;
            padding: 20px;
            background-color: #f0f0f0;
        }
        .product-container {
            background-color: white;
            padding: 20px;
            border-radius: 5px;
            box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
        }
        h1 {
            color: #333;
        }
        .product-details {
            margin-top: 20px;
        }
        .product-details p {
            margin: 10px 0;
        }
        .label {
            font-weight: bold;
        }
        .actions {
            margin-top: 20px;
        }
        .actions a {
            display: inline-block;
            margin-right: 10px;
            padding: 10px 20px;
            background-color: #4CAF50;
            color: white;
            text-decoration: none;
            border-radius: 4px;
        }
        .actions a:hover {
            background-color: #45a049;
        }
        .actions a.delete {
            background-color: #f44336;
        }
        .actions a.delete:hover {
            background-color: #da190b;
        }
    </style>
</head>
<body>
    <div class="product-container">
        <h1><?php echo htmlspecialchars($product['name']); ?></h1>
        <div class="product-details">
            <p><span class="label">SKU:</span> <?php echo htmlspecialchars($product['sku']); ?></p>
            <p><span class="label">Description:</span> <?php echo nl2br(htmlspecialchars($product['description'])); ?></p>
            <p><span class="label">Price:</span> $<?php echo number_format($product['price'], 2); ?></p>
            <p><span class="label">Stock Quantity:</span> <?php echo $product['stock_quantity']; ?></p>
            <p><span class="label">Category:</span> <?php echo htmlspecialchars($product['category']); ?></p>
            <p><span class="label">Brand:</span> <?php echo htmlspecialchars($product['brand']); ?></p>
            <p><span class="label">Weight:</span> <?php echo $product['weight']; ?></p>
            <p><span class="label">Dimensions:</span> <?php echo htmlspecialchars($product['dimensions']); ?></p>
        </div>
        <div class="actions">
            <a href="edit_product.php?id=<?php echo $product['id']; ?>">Edit Product</a>
            <a href="delete_product.php?id=<?php echo $product['id']; ?>" onclick="return confirm('Are you sure you want to delete this product?');">Delete</a>
            <a href="product_list.php">Back to Product List</a>
            <a href="generate_qr.php?id=<?php echo $product['id']; ?>&format=png" target="_blank">QR (PNG)</a>
            <a href="generate_qr.php?id=<?php echo $product['id']; ?>&format=jpg" target="_blank">QR (JPG)</a>
        </div>
    </div>
</body>
</html>